<?php
/**
 * This file is part of Advanced Custom Fields: Carousel.
 *
 * Advanced Custom Fields: Carousel is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 2 of the License, or any later version.
 *
 * Advanced Custom Fields: Carousel is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Advanced Custom Fields: Carousel.  If not, see <https://www.gnu.org/licenses/>.
 */

declare( strict_types=1 );

namespace AcfCarousel;

use AcfCarousel\Carousel\Block as CarouselBlock;
use Throwable;

/**
 * Initializes the plugin’s classes and hooks.
 *
 * @since 20220719
 */
class Bootstrap {

	/**
	 * Bootstrap constructor.
	 *
	 * @param string $plugin_file The full path to the plugin’s root file.
	 *
	 * @since 20220719
	 */
	public function __construct( string $plugin_file ) {
		$this->setup_translation( $plugin_file );
		$this->load_classes( $plugin_file );
	}

	/**
	 * Sets up WordPress’ gettext for this plugin.
	 *
	 * @param string $plugin_file The full path to the plugin’s root file.
	 *
	 * @since 20220719
	 */
	private function setup_translation( string $plugin_file ): void {
		load_plugin_textdomain(
			'acf-carousel',
			false,
			dirname( plugin_basename( $plugin_file ) ) . '/languages'
		);
	}

	/**
	 * Instantiates the plugin’s classes according to the type of request.
	 *
	 * @param string $plugin_file The full path to the plugin’s root file.
	 *
	 * @since 20220719
	 */
	private function load_classes( string $plugin_file ): void {
		$classes = [
			CarouselBlock::class,
		];
		foreach ( $classes as $class ) {
			try {
				new $class( $plugin_file ); // phpcs:ignore NeutronStandard.Functions.VariableFunctions
			} catch ( Throwable $e ) {
				$title = __( 'Advanced Custom Fields: Carousel Initialization Failed', 'acf-carousel' );
				$message = sprintf(
				// Translators: %1$s is full class name, %2$s is exception message.
					__( '<p>Failed to load class “%1$s”.</p><p><strong>Error</strong>: %2$s.</p>', 'acf-carousel' ),
					$class,
					$e->getMessage()
				);
				wp_die( $message, $title );
			}
		}
	}
}
