/**
 * This file is part of Advanced Custom Fields: Carousel.
 *
 * Advanced Custom Fields: Carousel is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 2 of the License, or any later version.
 *
 * Advanced Custom Fields: Carousel is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Advanced Custom Fields: Carousel.  If not, see <https://www.gnu.org/licenses/>.
 */

import jQuery from 'jquery';
// noinspection ES6UnusedImports
import slick from 'slick-carousel';
import './frontend.css';
import 'slick-carousel/slick/slick.scss';
import SimpleLightbox from "simplelightbox";
import "simplelightbox/src/simple-lightbox.scss";
import "./simple-lightbox.scss"

jQuery( document ).ready( ( $ ) => {
	function initLightBox( elements ) {
		new SimpleLightbox( elements, {
			overlayOpacity: 1,
			navText: ['', ''],
			closeText: '',
			captionSelector: 'self',
		} );
	}

	function initSingleImages() {
		const singleImages = document.querySelectorAll( '.wp-block-tandem-acf-carousel a[rel="lightbox"]' );
		const singleImagesLen = singleImages.length;
		for ( let i = 0; i < singleImagesLen; i ++ ) {
			initLightBox( singleImages[i] );
		}
	}

	function initGalleries() {
		const galleries = document.querySelectorAll( '.wp-block-tandem-acf-carousel[data-lightbox]' );
		const galleriesLen = galleries.length;
		for ( let i = 0; i < galleriesLen; i ++ ) {
			const gallery = galleries[i];
			const galleryId = gallery.dataset['lightbox'];
			initLightBox( gallery.querySelectorAll( 'a[rel="' + galleryId + '"]' ) )
		}
	}

	initSingleImages();
	initGalleries();

	$( '.acf-carousel' ).each( ( idx, el ) => {
		const $el = $( el );
		const $slides = $el.find( '.acf-carousel-slides' );
		const setWidth = () => $el.css( '--acf-carousel-width', $slides.width() + 'px' );
		$el.on( 'init', setWidth );
		$( window ).on( 'resize', setWidth );
		$el.on( 'init', function ( event, slick, currentSlide ) {
			const current = currentSlide ? currentSlide : 0;
			if ( current === 0 ) {
				$( '.slick-prev' ).on( 'click', function () {
					$slides.slick( 'slickGoTo', (
						slick.slideCount - 1
					) );
				} )
			}
		} );

		$el.on( 'afterChange', function ( event, slick, currentSlide ) {
			if ( slick.slideCount - 1 === currentSlide ) {
				$( '.slick-next' ).on( 'click', function () {
					$slides.slick( 'slickGoTo', 0 );
				} )
			}
		} );
		$slides.slick( {
			slidesToShow: 1,
			slidesToScroll: 1,
			mobileFirst: true,
			prevArrow: $el.find( '.slick-prev' ),
			nextArrow: $el.find( '.slick-next' ),
		} );
	} );
} );
