/**
 * This file is part of Advanced Custom Fields: Carousel.
 *
 * Advanced Custom Fields: Carousel is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 2 of the License, or any later version.
 *
 * Advanced Custom Fields: Carousel is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Advanced Custom Fields: Carousel.  If not, see <https://www.gnu.org/licenses/>.
 */

import {__} from '@wordpress/i18n';
import {
	__experimentalNumberControl as NumberControl,
	PanelBody,
	Placeholder,
	TextControl,
	ToggleControl,
} from '@wordpress/components';
import {InspectorControls, useBlockProps,} from '@wordpress/block-editor';
import icon from './icon';

export default function edit( {attributes, setAttributes} ) {
	const {
		fieldName,
		useLightbox,
		lightboxGallery,
		variableWidth,
		adaptiveHeight,
		infinite,
		centerMode,
		desktopSlides,
		tabletSlides,
		mobileSlides,
	} = attributes;
	const templateSelect = <TextControl
		label={__( 'Gallery Field Name', 'acf-carousel' )}
		value={fieldName}
		onChange={( value ) => {
			setAttributes( {
				fieldName: value,
			} )
		}}
	/>;
	return (
		<div  {...useBlockProps()} >
			<InspectorControls>
				<PanelBody
					title={__( 'ACF Carousel Settings', 'acf-carousel' )}>
					{templateSelect}
					<ToggleControl
						label={__( 'Show images in a lightbox', 'acf-carousel' )}
						checked={useLightbox}
						onChange={( useLightbox ) => setAttributes( {useLightbox} )}
					/>
					{useLightbox &&
						<ToggleControl
							label={__( 'Show lightbox images as a gallery', 'acf-carousel' )}
							checked={lightboxGallery}
							onChange={( lightboxGallery ) => setAttributes( {lightboxGallery} )}
						/>
					}
				</PanelBody>
				<PanelBody
					title={__( 'Carousel Settings', 'acf-carousel' )}
				>
					<ToggleControl
						label={__( 'Variable Width', 'acf-carousel' )}
						checked={variableWidth}
						onChange={( variableWidth ) => setAttributes( {variableWidth} )}
					/>
					<ToggleControl
						label={__( 'Adaptive Height', 'acf-carousel' )}
						checked={adaptiveHeight}
						onChange={( adaptiveHeight ) => setAttributes( {adaptiveHeight} )}
					/>
					<ToggleControl
						label={__( 'Infinite', 'acf-carousel' )}
						checked={infinite}
						onChange={( infinite ) => setAttributes( {infinite} )}
					/>
					<ToggleControl
						label={__( 'Center Mode', 'acf-carousel' )}
						checked={centerMode}
						onChange={( centerMode ) => setAttributes( {centerMode} )}
					/>
				</PanelBody>
				{! variableWidth &&
					<PanelBody
						title={__( 'Slides', 'acf-carousel' )}
					>
						<NumberControl
							label={__( 'Desktop', 'acf-carousel' )}
							min="1"
							value={desktopSlides}
							onChange={( value ) => setAttributes( {
								desktopSlides: parseInt( value, 10 ),
							} )}
						/>
						<NumberControl
							label={__( 'Tablet', 'acf-carousel' )}
							min="1"
							value={tabletSlides}
							onChange={( value ) => setAttributes( {
								tabletSlides: parseInt( value, 10 ),
							} )}
						/>
						<NumberControl
							label={__( 'Mobile', 'acf-carousel' )}
							min="1"
							value={mobileSlides}
							onChange={( value ) => setAttributes( {
								mobileSlides: parseInt( value, 10 ),
							} )}
						/>
					</PanelBody>}
			</InspectorControls>
			<Placeholder icon={icon} label={__( 'ACF Carousel', 'acf-carousel' )}>
				{templateSelect}
			</Placeholder>
		</div>
	);
};
